@@ -38,9 +38,6 @@
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
-#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 6
-#include "xf86Resources.h"
-#endif
 #include "xf86cmap.h"
 #include "compiler.h"
 #include "mipointer.h"
@@ -73,12 +70,9 @@
 #define GX_GP_REG_SIZE  0x4000
 #define GX_VID_REG_SIZE 0x4000
 
-#define DEFAULT_IMG_LINE_BUFS 20
-#define DEFAULT_CLR_LINE_BUFS 20
-
 extern OptionInfoRec GX_GeodeOptions[];
 
-unsigned char *XpressROMPtr;
+extern unsigned char *XpressROMPtr;
 
 static inline void
 gx_enable_dac_power(void)
@@ -107,54 +101,6 @@ GXInitEXAMemory(ScrnInfoPtr pScrni, unsigned int *offset, unsigned int *avail)
     }
 }
 
-static void
-GXInitXAAMemory(ScrnInfoPtr pScrni, unsigned int *offset, unsigned int *avail)
-{
-    GeodePtr pGeode = GEODEPTR(pScrni);
-    unsigned int size, i, pitch;
-
-    /* XXX - FIXME - What if we are out of room?  Then what? */
-    /* For now, we NULL them all out.                        */
-
-    if (pGeode->NoOfImgBuffers > 0) {
-        size = pGeode->displayPitch * pGeode->NoOfImgBuffers;
-        if (size <= *avail) {
-            for (i = 0; i < pGeode->NoOfImgBuffers; i++) {
-                pGeode->AccelImageWriteBuffers[i] = pGeode->FBBase + *offset;
-                *offset += pGeode->displayPitch;
-                *avail -= pGeode->displayPitch;
-            }
-        }
-        else {
-            xf86DrvMsg(pScrni->scrnIndex, X_ERROR,
-                       "Not enough memory for image write buffers.\n");
-
-            for (i = 0; i < pGeode->NoOfImgBuffers; i++)
-                pGeode->AccelImageWriteBuffers[i] = NULL;
-        }
-    }
-
-    if (pGeode->NoOfColorExpandLines > 0) {
-        pitch = ((pGeode->displayPitch + 31) >> 5) << 2;
-        size = pitch * pGeode->NoOfColorExpandLines;
-
-        if (size <= *avail) {
-            for (i = 0; i < pGeode->NoOfColorExpandLines; i++) {
-                pGeode->AccelColorExpandBuffers[i] = pGeode->FBBase + *offset;
-                *offset += pitch;
-                *avail -= pitch;
-            }
-        }
-        else {
-            xf86DrvMsg(pScrni->scrnIndex, X_ERROR,
-                       "Not enough memory for color expansion buffers.\n");
-
-            for (i = 0; i < pGeode->NoOfImgBuffers; i++)
-                pGeode->AccelColorExpandBuffers[i] = NULL;
-        }
-    }
-}
-
 static Bool
 GXAllocateMemory(ScreenPtr pScrn, ScrnInfoPtr pScrni, int rotate)
 {
@@ -217,12 +163,8 @@ GXAllocateMemory(ScreenPtr pScrn, ScrnInfoPtr pScrni, int rotate)
         }
     }
 
-    if (!pGeode->NoAccel) {
-        if (pGeode->useEXA)
-            GXInitEXAMemory(pScrni, &fboffset, &fbavail);
-        else
-            GXInitXAAMemory(pScrni, &fboffset, &fbavail);
-    }
+    if (!pGeode->NoAccel && pGeode->useEXA)
+        GXInitEXAMemory(pScrni, &fboffset, &fbavail);
 
     pGeode->shadowSize = 0;
 
@@ -258,50 +200,6 @@ GXAllocateMemory(ScreenPtr pScrn, ScrnInfoPtr pScrni, int rotate)
             pExa->offScreenBase = fboffset;
             pExa->memorySize = fboffset + fbavail;
         }
-
-        if (!pGeode->useEXA) {
-
-#if XF86XAA
-            if (!xf86FBManagerRunning(pScrn)) {
-
-                unsigned int offset = fboffset;
-                unsigned int avail = fbavail;
-                RegionRec OffscreenRegion;
-                BoxRec AvailBox;
-
-                /* Assume the shadow FB exists even if it doesnt */
-
-                if (pGeode->shadowSize == 0) {
-                    size = (pScrn->width * bytpp) * pScrni->virtualX;
-                    offset += size;
-                    avail -= size;
-                }
-
-                AvailBox.x1 = 0;
-                AvailBox.y1 =
-                    (offset + pGeode->displayPitch - 1) / pGeode->displayPitch;
-
-                AvailBox.x2 = pGeode->displayWidth;
-                AvailBox.y2 = (offset + avail) / pGeode->displayPitch;
-
-                if (AvailBox.y1 < AvailBox.y2) {
-                    REGION_INIT(pScrn, &OffscreenRegion, &AvailBox, 2);
-
-                    if (!xf86InitFBManagerRegion(pScrn, &OffscreenRegion))
-                        xf86DrvMsg(pScrni->scrnIndex, X_ERROR,
-                                   "Memory manager initialization failed.\n");
-
-                    REGION_UNINIT(pScrn, &OffscreenRegion);
-                }
-                else
-                    xf86DrvMsg(pScrni->scrnIndex, X_INFO,
-                               "Cache disabled - no offscreen memory available.\n");
-            }
-            else
-                xf86DrvMsg(pScrni->scrnIndex, X_INFO,
-                           "XAA offscreen memory has already been allocated.\n");
-#endif
-        }
     }
     return ret;
 }
@@ -386,11 +284,14 @@ GXMapMem(ScrnInfoPtr pScrni)
 #else
     {
         int fd = open("/dev/mem", O_RDWR);
+
         if (fd < 0) {
             xf86DrvMsg(index, X_ERROR, "Failed to open /dev/mem: %m\n");
             return FALSE;
         }
-        XpressROMPtr = mmap(NULL, 0x10000, PROT_READ | PROT_WRITE, MAP_SHARED, fd, 0xF0000);
+        XpressROMPtr =
+            mmap(NULL, 0x10000, PROT_READ | PROT_WRITE, MAP_SHARED, fd,
+                 0xF0000);
         close(fd);
     }
 #endif
@@ -450,7 +351,7 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
     EntityInfoPtr pEnt;
     rgb defaultWeight = { 0, 0, 0 };
     int modecnt;
-    char *s, *panelgeo;
+    const char *s, *panelgeo;
     Bool useVGA;
 
     if (pScrni->numEntities != 1)
@@ -462,7 +363,7 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
         return FALSE;
 #endif
 
-    pGeode = pScrni->driverPrivate = xnfcalloc(1, sizeof(GeodeRec));
+    pGeode = pScrni->driverPrivate = XNFcallocarray(1, sizeof(GeodeRec));
 
     if (pGeode == NULL)
         return FALSE;
@@ -554,8 +455,6 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
 
     pGeode->Panel = (pGeode->Output & OUTPUT_PANEL) ? TRUE : FALSE;
 
-    pGeode->NoOfImgBuffers = DEFAULT_IMG_LINE_BUFS;
-    pGeode->NoOfColorExpandLines = DEFAULT_CLR_LINE_BUFS;
     pGeode->exaBfrSz = DEFAULT_EXA_SCRATCH_BFRSZ;
 
     xf86GetOptValBool(GeodeOptions, GX_OPTION_HW_CURSOR, &pGeode->tryHWCursor);
@@ -564,7 +463,7 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
                               (int *) &(pGeode->FBAvail)))
         pGeode->FBAvail = 0;
 
-    /* For compatability - allow SWCursor too */
+    /* For compatibility - allow SWCursor too */
 
     if (xf86ReturnOptValBool(GeodeOptions, GX_OPTION_SW_CURSOR, FALSE))
         pGeode->tryHWCursor = FALSE;
@@ -589,17 +488,9 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
             xf86DrvMsg(pScrni->scrnIndex, X_ERROR, "Invalid rotation %s.\n", s);
     }
 
-    xf86GetOptValInteger(GeodeOptions, GX_OPTION_OSM_IMG_BUFS,
-                         &(pGeode->NoOfImgBuffers));
-
-    if (pGeode->NoOfImgBuffers <= 0)
-        pGeode->NoOfImgBuffers = 0;
-
-    xf86GetOptValInteger(GeodeOptions, GX_OPTION_OSM_CLR_BUFS,
-                         &(pGeode->NoOfColorExpandLines));
-
-    if (pGeode->NoOfColorExpandLines <= 0)
-        pGeode->NoOfColorExpandLines = 0;
+    if ((s = xf86GetOptValString(GeodeOptions, GX_OPTION_OSM_IMG_BUFS)))
+        xf86DrvMsg(pScrni->scrnIndex, X_WARNING,
+                   "XAA not present so OSMImageBuffers is ignored");
 
     xf86GetOptValInteger(GeodeOptions, GX_OPTION_OSM_CLR_BUFS,
                          (int *) &(pGeode->exaBfrSz));
@@ -615,23 +506,17 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
     panelgeo = xf86GetOptValString(GeodeOptions, GX_OPTION_PANEL_GEOMETRY);
 
     if ((s = xf86GetOptValString(GeodeOptions, GX_OPTION_ACCEL_METHOD))) {
-#if defined(XF86XAA) && defined(XF86EXA)
-        if (!xf86NameCmp(s, "XAA"))
-            pGeode->useEXA = FALSE;
-        else if (xf86NameCmp(s, "EXA"))
-            xf86DrvMsg(pScrni->scrnIndex, X_ERROR,
-                       "Unknown accleration method %s.  Defaulting to XAA.\n",
-                       s);
-#elif defined(XF86EXA)
+#if defined(XF86EXA)
         pGeode->useEXA = TRUE;
 #else
         pGeode->useEXA = FALSE;
+        pGeode->NoAccel = TRUE;
 #endif
     }
 
     xf86DrvMsg(pScrni->scrnIndex, X_INFO,
                "Using %s acceleration architecture\n",
-               pGeode->useEXA ? "EXA" : "XAA");
+               pGeode->useEXA ? "EXA" : "none");
 
     /* Set up the panel */
 
@@ -692,7 +577,7 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
     else
         pScrni->videoRam = pGeode->pEnt->device->videoRam;
 
-    GeodeClockRange = (ClockRangePtr) xnfcalloc(1, sizeof(ClockRange));
+    GeodeClockRange = (ClockRangePtr) XNFcallocarray(1, sizeof(ClockRange));
     GeodeClockRange->next = NULL;
     GeodeClockRange->minClock = 25175;
     GeodeClockRange->maxClock = 229500;
@@ -824,9 +709,8 @@ GXSetDvLineSize(unsigned int pitch)
 /* XXX - this is nothing like the original function - not sure exactly what the purpose is for this quite yet */
 
 static void
-GXAdjustFrame(ADJUST_FRAME_ARGS_DECL)
+GXAdjustFrame(ScrnInfoPtr pScrni, int x, int y)
 {
-    SCRN_INFO_PTR(arg);
     GeodeRec *pGeode = GEODEPTR(pScrni);
     unsigned long offset;
 
@@ -908,16 +792,15 @@ GXSetVideoMode(ScrnInfoPtr pScrni, DisplayModePtr pMode)
         pGeode->HWCursor = FALSE;
     }
 
-    GXAdjustFrame(ADJUST_FRAME_ARGS(pScrni->frameX0, pScrni->frameY0));
+    GXAdjustFrame(pScrni, pScrni->frameX0, pScrni->frameY0);
     gx_enable_dac_power();
 
     return TRUE;
 }
 
 static Bool
-GXSwitchMode(SWITCH_MODE_ARGS_DECL)
+GXSwitchMode(ScrnInfoPtr pScrni, DisplayModePtr pMode)
 {
-    SCRN_INFO_PTR(arg);
     GeodeRec *pGeode = GEODEPTR(pScrni);
     int ret = TRUE;
     int rotate;
@@ -1006,7 +889,7 @@ GXLeaveGraphics(ScrnInfoPtr pScrni)
 }
 
 static Bool
-GXCloseScreen(CLOSE_SCREEN_ARGS_DECL)
+GXCloseScreen(ScreenPtr pScrn)
 {
     ScrnInfoPtr pScrni = xf86ScreenToScrn(pScrn);
     GeodeRec *pGeode = GEODEPTR(pScrni);
@@ -1014,22 +897,6 @@ GXCloseScreen(CLOSE_SCREEN_ARGS_DECL)
     if (pScrni->vtSema)
         GXLeaveGraphics(pScrni);
 
-#ifdef XF86XAA
-    if (pGeode->AccelInfoRec)
-        XAADestroyInfoRec(pGeode->AccelInfoRec);
-#endif
-
-    if (pGeode->AccelImageWriteBuffers) {
-        free(pGeode->AccelImageWriteBuffers[0]);
-        free(pGeode->AccelImageWriteBuffers);
-        pGeode->AccelImageWriteBuffers = NULL;
-    }
-
-    if (pGeode->AccelColorExpandBuffers) {
-        free(pGeode->AccelColorExpandBuffers);
-        pGeode->AccelColorExpandBuffers = NULL;
-    }
-
     if (pGeode->pExa) {
         exaDriverFini(pScrn);
         free(pGeode->pExa);
@@ -1044,7 +911,7 @@ GXCloseScreen(CLOSE_SCREEN_ARGS_DECL)
     pScrn->CloseScreen = pGeode->CloseScreen;
 
     if (pScrn->CloseScreen)
-        return (*pScrn->CloseScreen) (CLOSE_SCREEN_ARGS);
+        return (*pScrn->CloseScreen) (pScrn);
 
     return TRUE;
 }
@@ -1135,7 +1002,7 @@ GXEnterGraphics(ScreenPtr pScrn, ScrnInfoPtr pScrni)
     }
 
     /* Set up the memory */
-    /* XXX - FIXME - when we alow inital rotation, it should be here */
+    /* XXX - FIXME - when we allow initial rotation, it should be here */
     GXAllocateMemory(pScrn, pScrni, pGeode->rotation);
 
     /* Clear the framebuffer */
@@ -1150,7 +1017,7 @@ GXEnterGraphics(ScreenPtr pScrn, ScrnInfoPtr pScrni)
 
 static void
 GXLoadPalette(ScrnInfoPtr pScrni,
-              int numColors, int *indizes, LOCO * colors, VisualPtr pVisual)
+              int numColors, int *indizes, LOCO *colors, VisualPtr pVisual)
 {
     int i, index, color;
 
@@ -1275,7 +1142,7 @@ GXCreateScreenResources(ScreenPtr pScreen)
 }
 
 static Bool
-GXScreenInit(SCREEN_INIT_ARGS_DECL)
+GXScreenInit(ScreenPtr pScrn, int argc, char **argv)
 {
     ScrnInfoPtr pScrni = xf86ScreenToScrn(pScrn);
     GeodeRec *pGeode = GEODEPTR(pScrni);
@@ -1294,38 +1161,26 @@ GXScreenInit(SCREEN_INIT_ARGS_DECL)
         vgaHWGetIOBase(VGAHWPTR(pScrni));
     }
 
-    if (!pGeode->NoAccel) {
-
-        if (pGeode->useEXA) {
-
-            if (!(pGeode->pExa = exaDriverAlloc())) {
-                xf86DrvMsg(pScrni->scrnIndex, X_ERROR,
-                           "Couldn't allocate the EXA structure.\n");
-                pGeode->NoAccel = TRUE;
-            }
-            else {
-                ExaDriverPtr pExa = pGeode->pExa;
-
-                /* THis is set in GXAllocMem */
-                pExa->memoryBase = 0;
-
-                /* This is set in GXAllocateMemory */
-                pExa->memorySize = 0;
-
-                pExa->pixmapOffsetAlign = 32;
-                pExa->pixmapPitchAlign = 32;
-                pExa->flags = EXA_OFFSCREEN_PIXMAPS;
-                pExa->maxX = GX_MAX_WIDTH - 1;
-                pExa->maxY = GX_MAX_HEIGHT - 1;
-            }
+    if (!pGeode->NoAccel && pGeode->useEXA) {
+        if (!(pGeode->pExa = exaDriverAlloc())) {
+            xf86DrvMsg(pScrni->scrnIndex, X_ERROR,
+                       "Couldn't allocate the EXA structure.\n");
+            pGeode->NoAccel = TRUE;
         }
         else {
-            pGeode->AccelImageWriteBuffers =
-                calloc(pGeode->NoOfImgBuffers,
-                       sizeof(pGeode->AccelImageWriteBuffers[0]));
-            pGeode->AccelColorExpandBuffers =
-                calloc(pGeode->NoOfColorExpandLines,
-                       sizeof(pGeode->AccelColorExpandBuffers[0]));
+            ExaDriverPtr pExa = pGeode->pExa;
+
+            /* THis is set in GXAllocMem */
+            pExa->memoryBase = 0;
+
+            /* This is set in GXAllocateMemory */
+            pExa->memorySize = 0;
+
+            pExa->pixmapOffsetAlign = 32;
+            pExa->pixmapPitchAlign = 32;
+            pExa->flags = EXA_OFFSCREEN_PIXMAPS;
+            pExa->maxX = GX_MAX_WIDTH - 1;
+            pExa->maxY = GX_MAX_HEIGHT - 1;
         }
     }
 
@@ -1475,9 +1330,8 @@ GXScreenInit(SCREEN_INIT_ARGS_DECL)
 }
 
 static int
-GXValidMode(VALID_MODE_ARGS_DECL)
+GXValidMode(ScrnInfoPtr pScrni, DisplayModePtr pMode, Bool Verbose, int flags)
 {
-    SCRN_INFO_PTR(arg);
     GeodeRec *pGeode = GEODEPTR(pScrni);
     int p;
     int custom = 0;
@@ -1526,16 +1380,14 @@ GXValidMode(VALID_MODE_ARGS_DECL)
 /* XXX - Way more to do here */
 
 static Bool
-GXEnterVT(VT_FUNC_ARGS_DECL)
+GXEnterVT(ScrnInfoPtr pScrni)
 {
-    SCRN_INFO_PTR(arg);
     return GXEnterGraphics(NULL, pScrni);
 }
 
 static void
-GXLeaveVT(VT_FUNC_ARGS_DECL)
+GXLeaveVT(ScrnInfoPtr pScrni)
 {
-    SCRN_INFO_PTR(arg);
     GeodeRec *pGeode = GEODEPTR(pScrni);
 
     pGeode->PrevDisplayOffset = gfx_get_display_offset();
@@ -1562,9 +1414,8 @@ GXSetupChipsetFPtr(ScrnInfoPtr pScrn)
  * ============================== */
 
 void
-GeodePointerMoved(POINTER_MOVED_ARGS_DECL)
+GeodePointerMoved(ScrnInfoPtr pScrni, int x, int y)
 {
-    SCRN_INFO_PTR(arg);
     GeodeRec *pGeode = GEODEPTR(pScrni);
 
     int newX = x, newY = y;
@@ -1586,7 +1437,7 @@ GeodePointerMoved(POINTER_MOVED_ARGS_DECL)
         break;
     }
 
-    (*pGeode->PointerMoved) (POINTER_MOVED_ARGS(newX, newY));
+    (*pGeode->PointerMoved) (pScrni, newX, newY);
 }
 
 int
@@ -1608,9 +1459,8 @@ GeodeFreeRec(ScrnInfoPtr pScrni)
 }
 
 void
-GeodeFreeScreen(FREE_SCREEN_ARGS_DECL)
+GeodeFreeScreen(ScrnInfoPtr pScrni)
 {
-    SCRN_INFO_PTR(arg);
     GeodeRec *pGeode = GEODEPTR(pScrni);
 
     if (pGeode == NULL)
@@ -1635,7 +1485,7 @@ GeodeCalculatePitchBytes(unsigned int width, unsigned int bpp)
     if (width < 640)
         delta <<= 1;
 
-    /* Calculate the pitch (compression rquires a power of 2) */
+    /* Calculate the pitch (compression requires a power of 2) */
 
     if (delta > 4096)
         delta = 8192;
